<?php

/*
	Plugin Name: TechStudio's Pinterest Button For Images
	Plugin URI: http://techstudio.co/wordpress/plugins/pinterest-button-for-images
	Description: There are many Pinterest button plugins for WordPress, but this one uses a PHP filter to add the classes to your content and it doesn't force you to load additional stylesheets or scripts. Keep it tidy.
	Version: 1.2
	Author: TechStudio
	Author URI: http://techstudio.co
	License: GPL2
*/

// Make sure environment meets plugin requirements
include('functions/requirements.php');

// Include libs and misc functions
include('libs/simple_html_dom.php');
include('functions/misc.php');

// Plugin Version
$tpbfi_version = '1.2';
$tpbfi_version_last_load = get_option('tpbfi_version');

// Plugin Options
$tpbfi_options = get_option('tpbfi_options');

// Register Styles/Scripts
wp_register_style( 'tpbfi-admin', plugins_url( 'css/admin.css' , __FILE__ ), false, $tpbfi_version, 'screen' );

// Print default styles into header
function tpbfi_default_style() {
	echo "\n\n";
	echo "<!-- WordPress : Plugin : TechStudio's Pinterest Button For Images : Default style -->\n";
	echo "<style>\n";
	echo tpbfi_get_include_contents(ABSPATH.'wp-content/plugins/techstudios-pinterest-button-for-images/css/default.css');
	echo "</style>\n";
	echo "<!-- /Default style -->\n\n";
}

// Print onclick function into footer
function tpbfi_onclick() {
	echo "\n\n";
	echo "<!-- WordPress : Plugin : TechStudio's Pinterest Button For Images : Onclick helper -->\n";
	echo "<script>\n";
	echo tpbfi_get_include_contents(ABSPATH.'wp-content/plugins/techstudios-pinterest-button-for-images/js/onclick.js');
	echo "</script>\n";
	echo "<!-- /Onclick helper -->\n\n";
}

// Enqueue Admin Styles/Scripts
if ( is_admin() && $_GET['page'] == 'tpbfi' ) {
	wp_enqueue_style('tpbfi-admin');
}

// Enqueue Styles/Scripts
if ( $tpbfi_options['css'] == 'enabled' )
	if ( is_admin() ) {
		add_action('admin_head','tpbfi_default_style');
	}
	else {
		add_action('wp_head','tpbfi_default_style');
	}
if ( $tpbfi_options['javascript'] == 'onclick' ) {
	if ( is_admin() )
		add_action('admin_footer','tpbfi_onclick');
	else
		add_action('wp_footer','tpbfi_onclick');
}

// Menu
function tpbfi_plugin_menu() {
	add_options_page( 'Pinterest Button For Images', 'Pinterest Button For Images', 'manage_options', 'tpbfi', 'tpbfi_options' );
}
add_action('admin_menu', 'tpbfi_plugin_menu');

// Set Plugin Default If It Hasn't Been Installed Before ... this should only happen once in history
function tpbfi_add_defaults() {
	$default_options = array(
		'css' => 'enabled',
		'javascript' => 'onclick',
		'img' => 'enabled',
		'exclude_img_class_id_list' => '.tpbfi-exclude',
    	'exclude_img_width' => 64,
		'exclude_img_height' => 64,
		'imga' => 'enabled',
		'exclude_imga_class_id_list' => '.tpbfi-exclude',
    	'exclude_imga_width' => 64,
		'exclude_imga_height' => 64,
		'exclude_imga_target_blank' => 'enabled',
		'exclude_imga_rel_external' => 'enabled',
	);
	update_option('tpbfi_options', $default_options);
}

// Options Page
function tpbfi_options() {
	include('functions/options.php');
}

// First install
if ( !isset($tpbfi_version_last_load) ) {
	add_action('admin_init','tpbfi_add_defaults');
}

// Upgrade, not a first install
if ( isset($tpbfi_version_last_load) && $tpbfi_version != $tpbfi_version_last_load ) {
	// Do some stuff for upgrade
}

// Set Version
add_option('tpbfi_version',$tpbfi_version);

// The Filter : where the magic happens
include 'functions/filter.php';
add_filter( 'the_content', 'tpbfi_filter', 9999 );

?>
